/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla Schema Validation.
 *
 * The Initial Developer of the Original Code is
 * IBM Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2005
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"
#include "nsISchema.idl"
#include "nsISchemaDuration.idl"
#include "nsIDOMNode.idl"

[scriptable, uuid(eced2af3-fde9-4575-b5a4-e1c830b24611)]
interface nsISchemaValidator : nsISupports {
  void loadSchema(in nsISchema aSchema);
  boolean validate(in nsIDOMNode aElement);
  boolean validateString(in AString aValue, in AString aType, in AString aNamespace);
  boolean validateAgainstType(in nsIDOMNode aElement, in nsISchemaType aType);

  nsISchemaType getType(in AString aType, in AString aNamespace);

  // methods to validate and parse schema builtin types
  nsISchemaDuration validateBuiltinTypeDuration(in AString aValue);
  PRTime validateBuiltinTypeTime(in AString aValue);
  PRTime validateBuiltinTypeDate(in AString aValue);
  PRTime validateBuiltinTypeDateTime(in AString aValue);
};

